//
//  ViewController.swift
//  AppnextNativeAdsSDKSwiftTest
//
//  Created by Eran Mausner on 29/08/2016.
//  Copyright © 2016 Appnext. All rights reserved.
//

import UIKit

class ViewController: UIViewController, UITableViewDataSource, UITableViewDelegate, AppnextNativeAdsSwiftTestTableViewCellDelegate, AppnextNativeAdsRequestDelegate, AppnextNativeAdOpenedDelegate {

    var api:AppnextNativeAdsSDKApi?
    var adsArray:NSArray! = NSArray()

    @IBOutlet var countField: UITextField!
    @IBOutlet var adsTableView: UITableView!

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        self.countField.text = "10"
        self.api = AppnextNativeAdsSDKApi.init(placementID: "PUT-YOUR-PLACEMENT-HERE")
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: Internal

    func showActivity() {
        self.view.userInteractionEnabled = false
        self.view.makeToastActivity()
    }

    func hideActivity() {
        self.view.userInteractionEnabled = true
        self.view.hideToastActivity()
    }

    // MARK: Actions

    @IBAction func loadAds(sender: AnyObject) {
        self.countField.resignFirstResponder()
        let request:AppnextNativeAdsRequest = AppnextNativeAdsRequest()
        if let count = UInt(self.countField.text!) {
            request.count = count
        } else {
            request.count = 1
        }
        self.api!.loadAds(request, withRequestDelegate:self)
        self.showActivity()
    }

    // MARK: AppnextNativeAdsRequestDelegate

    func onAdsLoaded(ads: [AppnextAdData]!, forRequest request: AppnextNativeAdsRequest!) {
        self.hideActivity()
        let description = String(format:"onAdsLoaded:")
        NSLog("%@", description)
        self.adsArray = NSArray.init(array: ads)
        self.adsTableView.reloadData()
    }

    func onError(error: String!, forRequest request: AppnextNativeAdsRequest!) {
        self.hideActivity()
        let description = String(format:"onError:forRequest: %@", error)
        NSLog("%@", description)
        self.view.makeToast(description)
        self.adsArray = NSArray()
        self.adsTableView.reloadData()
    }

    // MARK: AppnextNativeAdOpenedDelegate

    func storeOpened(adData: AppnextAdData!) {
        self.hideActivity();
        let description = String(format:"storeOpened: for - %@", adData.title)
        NSLog("%@", description)
    }

    func onError(error: String!, forAdData adData: AppnextAdData!) {
        self.hideActivity();
        let description = String(format:"onError:forAdData: - %@", error)
        NSLog("%@", description)
        self.view.makeToast(description)
    }

    // MARK: AppnextNativeAdsTestTableViewCellDelegate

    func adClicked(cell: AppnextNativeAdsSwiftTestTableViewCell) {
        if let data = cell.adData {
            self.showActivity()
            self.api!.adClicked(data, withAdOpenedDelegate:self)
        }
    }

    func impressionClicked(cell: AppnextNativeAdsSwiftTestTableViewCell) {
        if let data = cell.adData {
            self.api!.adImpression(data)
        }
    }

    func videoStartedClicked(cell: AppnextNativeAdsSwiftTestTableViewCell) {
        if let data = cell.adData {
            self.api!.videoStarted(data)
        }
    }

    func videoEndedClicked(cell: AppnextNativeAdsSwiftTestTableViewCell) {
        if let data = cell.adData {
            self.api!.videoEnded(data)
        }
    }

    // MARK: UITableViewDataSource

    func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.adsArray.count
    }

    func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell:AppnextNativeAdsSwiftTestTableViewCell = tableView.dequeueReusableCellWithIdentifier("AdsCell") as! AppnextNativeAdsSwiftTestTableViewCell
        let row:Int = indexPath.row
        var adData:AppnextAdData?
        if (row < self.adsArray.count) {
            adData = self.adsArray.objectAtIndex(row) as? AppnextAdData
        }

        cell.adData = adData
        cell.delegate = self
        cell.reloadViews()
        return cell
    }

    // MARK: UITableViewDelegate

    func tableView(tableView: UITableView, willDisplayCell cell: UITableViewCell, forRowAtIndexPath indexPath: NSIndexPath) {
        if let nativeCell = cell as? AppnextNativeAdsSwiftTestTableViewCell {
            if let data = nativeCell.adData {
                self.api!.adImpression(data)
            }
        }
    }
}
