//
//  ViewController.swift
//  AppnextNewNativeLibSDKSwiftTest
//
//  Created by Eran Mausner on 02/02/2016.
//  Copyright © 2016 Appnext. All rights reserved.
//

import UIKit

class ViewController: UIViewController, AppnextVideoAdDelegate {

    var interstitial: AppnextInterstitialAd?
    var fullScreen: AppnextFullScreenVideoAd?
    var rewarded: AppnextRewardedVideoAd?

    override func viewDidLoad() {
        super.viewDidLoad()

        let config: AppnextInterstitialAdConfiguration = AppnextInterstitialAdConfiguration()
        config.autoPlay = true
        config.creativeType = ANCreativeType.Managed
        self.interstitial = AppnextInterstitialAd.init(config: config, placementID: "PUT-YOUR-PLACEMENT-HERE")
        self.interstitial?.delegate = self

        let fullScreenConfig: AppnextFullScreenVideoAdConfiguration = AppnextFullScreenVideoAdConfiguration()
        self.fullScreen = AppnextFullScreenVideoAd.init(config: fullScreenConfig, placementID: "PUT-YOUR-PLACEMENT-HERE")
        self.fullScreen?.delegate = self

        let rewardedConfig: AppnextRewardedVideoAdConfiguration = AppnextRewardedVideoAdConfiguration()
        self.rewarded = AppnextRewardedVideoAd.init(config: rewardedConfig, placementID: "PUT-YOUR-PLACEMENT-HERE")
        self.rewarded?.delegate = self

        let rewardedPostbackParams: AppnextRewardedServerSidePostbackParams = AppnextRewardedServerSidePostbackParams()
        rewardedPostbackParams.rewardsTransactionId = "Eran_Trrans";
        rewardedPostbackParams.rewardsUserId = "Eran_User";
        rewardedPostbackParams.rewardsRewardTypeCurrency = "Eran_RewardTypeCurrr";
        rewardedPostbackParams.rewardsAmountRewarded = "Eran_Amount";
        rewardedPostbackParams.rewardsCustomParameter = "Eran_Custom";
        self.rewarded?.setRewardedServerSidePostbackParams(rewardedPostbackParams)
    }

    // MARK: - Orientation

    override func shouldAutorotate() -> Bool {
        return true
    }

    override func supportedInterfaceOrientations() -> UIInterfaceOrientationMask {
        return UIInterfaceOrientationMask.Portrait
    }

    // MARK: - Actions

    @IBAction func getECPMInterstitial(sender: AnyObject) {
        self.interstitial?.getECPM()
    }

    @IBAction func loadInterstitial(sender: AnyObject) {
        self.interstitial?.loadAd()
    }

    @IBAction func showInterstitial(sender: AnyObject) {
        self.interstitial?.showAd()
    }

    @IBAction func getECPMVideo(sender: AnyObject) {
        self.fullScreen?.getECPM()
    }

    @IBAction func loadVideo(sender: AnyObject) {
        self.fullScreen?.loadAd()
    }

    @IBAction func showVideo(sender: AnyObject) {
        self.fullScreen?.showAd()
    }

    @IBAction func getECPMRewarded(sender: AnyObject) {
        self.rewarded?.getECPM()
    }

    @IBAction func loadRewarded(sender: AnyObject) {
        self.rewarded?.loadAd()
    }

    @IBAction func showRewarded(sender: AnyObject) {
        self.rewarded?.showAd()
    }

    // MARK: - AppnextVideoAdDelegate

    func adGetECPM(ad: AppnextAd!, withBannerECPM bannerECPM: AppnextBannerECPM!) {
        let message: String = "adGetECPM banner: " + bannerECPM.bannerId + ", ecpm: " + bannerECPM.ecpm + ", ppr: " + bannerECPM.ppr
        NSLog(message)
        self.view.makeToast(message)
    }

    func adLoaded(ad: AppnextAd!) {
        let str : String = "adLoaded " + String(ad.classForCoder);
        NSLog(str)
        self.view.makeToast(str)
    }

    func adOpened(ad: AppnextAd!) {
        let str : String = "adOpened " + String(ad.classForCoder);
        NSLog(str)
        self.view.makeToast(str)
    }

    func adClosed(ad: AppnextAd!) {
        let str : String = "adClosed " + String(ad.classForCoder);
        NSLog(str)
        self.view.makeToast(str)
    }

    func adClicked(ad: AppnextAd!) {
        let str : String = "adClicked " + String(ad.classForCoder);
        NSLog(str)
        self.view.makeToast(str)
    }

    func adUserWillLeaveApplication(ad: AppnextAd!) {
        let str : String = "adUserWillLeaveApplication " + String(ad.classForCoder);
        NSLog(str)
        self.view.makeToast(str)
    }

    func adError(ad: AppnextAd!, error: String!) {
        let str : String = "adError " + String(ad.classForCoder) + " " +  error;
        NSLog(str)
        self.view.makeToast(str)
    }

    func videoEnded(ad: AppnextAd!) {
        let str : String = "videoEnded " + String(ad.classForCoder);
        NSLog(str)
        self.view.makeToast(str)
    }
}

