//
//  ViewController.m
//  AppnextNewNativeLibSDKTest
//
//  Created by Eran Mausner on 10/01/2016.
//  Copyright © 2016 Appnext. All rights reserved.
//

#import "ViewController.h"
#import <AppnextLib/AppnextLib.h>
#import "UIView+Toast.h"

@interface ViewController ()<AppnextVideoAdDelegate>

@property (nonatomic, strong) AppnextInterstitialAd *interstitial;
@property (nonatomic, strong) AppnextFullScreenVideoAd *fullScreen;
@property (nonatomic, strong) AppnextRewardedVideoAd *rewarded;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    AppnextInterstitialAdConfiguration *interstitialConfig = [[AppnextInterstitialAdConfiguration alloc] init];
    interstitialConfig.autoPlay = YES;
    interstitialConfig.creativeType = ANCreativeTypeManaged;
    self.interstitial = [[AppnextInterstitialAd alloc] initWithConfig:interstitialConfig placementID:@"PUT-YOUR-PLACEMENT-HERE"];
    self.interstitial.delegate = self;
    
    AppnextFullScreenVideoAdConfiguration *fullScreenConfig = [[AppnextFullScreenVideoAdConfiguration alloc] init];
    self.fullScreen = [[AppnextFullScreenVideoAd alloc] initWithConfig:fullScreenConfig placementID:@"PUT-YOUR-PLACEMENT-HERE"];
    self.fullScreen.delegate = self;
    
    AppnextRewardedVideoAdConfiguration *rewardedConfig = [[AppnextRewardedVideoAdConfiguration alloc] init];
    self.rewarded = [[AppnextRewardedVideoAd alloc] initWithConfig:rewardedConfig placementID:@"PUT-YOUR-PLACEMENT-HERE"];
    self.rewarded.delegate = self;
//    AppnextRewardedServerSidePostbackParams *params = [[AppnextRewardedServerSidePostbackParams alloc] init];
//    params.rewardsTransactionId = @"Eran_Trrans";
//    params.rewardsUserId = @"Eran_User";
//    params.rewardsRewardTypeCurrency = @"Eran_RewardTypeCurrr";
//    params.rewardsAmountRewarded = @"Eran_Amount";
//    params.rewardsCustomParameter = @"Eran_Custom";
//    [self.rewarded setRewardedServerSidePostbackParams:params];
}

#pragma mark - Actions

- (IBAction) getECPMFromInterstitial:(id)sender
{
    [self.interstitial getECPM];
}

- (IBAction) loadInterstitial:(id)sender
{
    [self.interstitial loadAd];
}

- (IBAction) showInterstitial:(id)sender
{
    [self.interstitial showAd];
}

- (IBAction) getECPMFromVideo:(id)sender
{
    [self.fullScreen getECPM];
}

- (IBAction) loadVideo:(id)sender
{
    [self.fullScreen loadAd];
}

- (IBAction) showVideo:(id)sender
{
    [self.fullScreen showAd];
}

- (IBAction) getECPMFromRewarded:(id)sender
{
    [self.rewarded getECPM];
}

- (IBAction) loadRewarded:(id)sender
{
    [self.rewarded loadAd];
}

- (IBAction) showRewarded:(id)sender
{
    [self.rewarded showAd];
}

#pragma mark - AppnextVideoAdDelegate

- (void) adGetECPM:(AppnextAd *)ad withBannerECPM:(AppnextBannerECPM *)bannerECPM
{
    NSString *str = [NSString stringWithFormat:@"adGetECPM - %@, banner:%@, ecpm:%@, ppr:%@", ad.class, (bannerECPM ? bannerECPM.bannerId : @""), (bannerECPM ? bannerECPM.ecpm : @""), (bannerECPM ? bannerECPM.ppr : @"")];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

- (void) adLoaded:(AppnextAd *)ad
{
    NSString *str = [NSString stringWithFormat:@"adLoaded %@", ad.class];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

- (void) adOpened:(AppnextAd *)ad
{
    NSString *str = [NSString stringWithFormat:@"adOpened %@", ad.class];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

- (void) adClosed:(AppnextAd *)ad
{
    NSString *str = [NSString stringWithFormat:@"adClosed %@", ad.class];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

- (void) adClicked:(AppnextAd *)ad
{
    NSString *str = [NSString stringWithFormat:@"adClicked %@", ad.class];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

- (void) adUserWillLeaveApplication:(AppnextAd *)ad
{
    NSString *str = [NSString stringWithFormat:@"adUserWillLeaveApplication %@", ad.class];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

- (void) adError:(AppnextAd *)ad error:(NSString *)error
{
    NSString *showError = [NSString stringWithFormat:@"adError : %@", error];
    NSLog(@"%@", showError);
    [self.view makeToast:showError];
}

- (void) videoEnded:(AppnextAd *)ad
{
    NSString *str = [NSString stringWithFormat:@"videoEnded %@", ad.class];
    NSLog(@"%@", str);
    [self.view makeToast:str];
}

@end
